/*
 * This file contains model number definitions for the CUPS sample
 * ESC/P driver.
 *
 * Copyright 2007 by Apple Inc.
 * Copyright 1997-2005 by Easy Software Products.
 *
 * These coded instructions, statements, and computer programs are the
 * property of Apple Inc. and are protected by Federal copyright
 * law.  Distribution and use rights are outlined in the file "LICENSE.txt"
 * which should have been included with this file.  If this file is
 * missing or damaged, see the license at "http://www.cups.org/".
 */

#define EPSON_9PIN	0		/* 9-pin dot matrix */
#define EPSON_24PIN	1		/* 24-pin dot matrix */
#define EPSON_COLOR	2		/* Epson Stylus Color with ESC . */
#define EPSON_PHOTO	3		/* Epson Stylus Photo with ESC . */
#define EPSON_ICOLOR	4		/* Epson Stylus Color with ESC i */
#define EPSON_IPHOTO	5		/* Epson Stylus Photo with ESC i */
