/*
 * This file contains model number definitions for the CUPS sample
 * HP driver.
 *
 * Copyright 2007 by Apple Inc.
 * Copyright 1997-2005 by Easy Software Products.
 *
 * These coded instructions, statements, and computer programs are the
 * property of Apple Inc. and are protected by Federal copyright
 * law.  Distribution and use rights are outlined in the file "LICENSE.txt"
 * which should have been included with this file.  If this file is
 * missing or damaged, see the license at "http://www.cups.org/".
 */

#define HP_LASERJET	0		/* HP LaserJet */
#define HP_DESKJET	1		/* HP DeskJet with simple color */
#define HP_DESKJET2	2		/* HP DeskJet with CRet color */
